"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _Ban_user;
Object.defineProperty(exports, "__esModule", { value: true });
exports.Ban = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const Base_1 = require("./Base");
const Comment_1 = require("./Comment");
const Content_1 = require("./Content");
/**
 * Represents a complete Ban Object on iFunny
 * @extends Base<APIBan>
 */
class Ban extends Base_1.Base {
    /**
     * @param user User the ban is attached to
     * @param payload The payload of the Ban
     */
    constructor(user, payload) {
        super(user.client, payload);
        /**
         * The user attached to the Ban
         */
        _Ban_user.set(this, void 0);
        __classPrivateFieldSet(this, _Ban_user, user, "f");
        this.endpointUrl = ifunny_api_types_1.Endpoints.bans(user.id, payload.id);
    }
    /**
     * The user attached to the Ban
     */
    get user() {
        return __classPrivateFieldGet(this, _Ban_user, "f");
    }
    /**
     * The type of ban
     */
    get type() {
        return this.get("type");
    }
    /**
     * Timestamp of when the Ban expires
     */
    get expiresAt() {
        return new Date(this.get("date_until") * 1000);
    }
    /**
     * How long (in miliseconds) until the Ban expires
     */
    get expiresIn() {
        return this.expiresAt.getTime() - new Date().getTime();
    }
    /**
     * The reason for the Ban
     */
    get reason() {
        return this.get("ban_reason");
    }
    /**
     * The ban reason message
     */
    get reasonMessage() {
        return this.get("ban_reason_message");
    }
    /**
     * Can the ban be appealed?
     */
    get canBeAppealed() {
        return this.get("can_be_appealed");
    }
    /**
     * When the ban was created
     */
    get createdAt() {
        return new Date(this.get("created_at") * 1000);
    }
    /**
     * Not sure what this is
     */
    get dateUntilMinimum() {
        return this.get("date_until_minimum");
    }
    /**
     * Is the Ban active?
     */
    get isActive() {
        return this.get("is_active");
    }
    /**
     * Has the Ban be appealed?
     */
    get isAppealed() {
        return this.get("is_appealed");
    }
    /**
     * Is the ban shortable?
     */
    get isShortable() {
        return this.get("is_shortable");
    }
    /**
     * Don't know what this is yet
     */
    get pid() {
        // TODO: Document what pid is
        return this.get("pid");
    }
    /**
     * The Comment related to the Ban if applicable
     */
    get relatedComment() {
        const comment = this.get("related_comment");
        if (!comment)
            return null;
        if (!comment.content)
            return null;
        const content = new Content_1.Content(this.client, comment.content);
        return new Comment_1.Comment(content, comment);
    }
    /**
     * The Content related to the Ban if applicable
     */
    get relatedContent() {
        const content = this.get("related_content");
        return content ? new Content_1.Content(this.client, content) : null;
    }
    /**
     * The Ban Type message
     */
    get typeMessage() {
        return this.get("type_message");
    }
    /**
     * Was the Ban shown to the Client?
     */
    get wasShown() {
        return this.get("was_shown");
    }
}
exports.Ban = Ban;
_Ban_user = new WeakMap();
exports.default = Ban;
//# sourceMappingURL=Ban.js.map