"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _BaseComment_author, _BaseComment_content;
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseComment = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const Base_1 = require("./Base");
const Comment_1 = require("./Comment");
const SimpleUser_1 = require("./SimpleUser");
const Thumbnail_1 = require("./Thumbnail");
/**
 * Represents a BaseComment on iFunny
 * @extends Base<APIComment>
 */
class BaseComment extends Base_1.Base {
    /**
     * @param content Content the Comment is attached to
     * @param payload Payload of the Comment
     */
    constructor(content, payload) {
        super(content.client, payload);
        /**
         * The author of the comment
         */
        _BaseComment_author.set(this, null);
        /**
         * The content of the comment
         */
        _BaseComment_content.set(this, void 0);
        __classPrivateFieldSet(this, _BaseComment_content, content, "f");
        this.endpointUrl = ifunny_api_types_1.Endpoints.comments(this.content.id, this.payload.id);
    }
    /**
     * Content ID the comment is attached to
     */
    get contentId() {
        return this.get("cid");
    }
    /**
     * Content attached to the Comment
     */
    get content() {
        return __classPrivateFieldGet(this, _BaseComment_content, "f");
    }
    /**
     * Thumbnails for the content
     */
    get thumbnails() {
        const thumbs = this.get("content_thumbs");
        return thumbs ? new Thumbnail_1.Thumbnail(thumbs) : null;
    }
    /**
     * Returns the date when the comment was created.
     * @returns The comment's date as a `Date` object.
     */
    get date() {
        return new Date(this.get("date") * 1000);
    }
    /**
     * Whether the comment has been edited.
     * @returns True if the comment has been edited, false otherwise.
     */
    get isEdited() {
        return this.get("is_edited");
    }
    /**
     * Whether the comment is a reply to another comment.
     * @returns True if the comment is a reply, false otherwise.
     */
    get isReply() {
        return this.get("is_reply");
    }
    /**
     * Whether the comment has been smiled by the user.
     * @returns True if the comment has been smiled, false otherwise.
     */
    get isSmiled() {
        return this.get("is_smiled");
    }
    /**
     * Whether the user has un-smiled the comment.
     * @returns True if the comment has been un-smiled, false otherwise.
     */
    get isUnsmiled() {
        return this.get("is_unsmiled");
    }
    /**
     * The last reply to the comment.
     * @returns The last reply to the comment, or null if there are no replies.
     */
    get lastReply() {
        const reply = this.get("last_reply");
        return reply ? new Comment_1.Comment(this.content, reply) : null;
    }
    /**
     * The number of the comment.
     * @returns The number of the comment.
     */
    get num() {
        return this.get("num");
    }
    /**
     * The state of the comment.
     * @returns The state of the comment, or null if the state is not available.
     */
    get state() {
        return this.get("state");
    }
    /**
     * The text of the Comment. Can be an empty string
     */
    get text() {
        return this.get("text");
    }
    /**
     * Author of the Comment
     * @alias creator
     * @example
     * const author = comment.author; // SimpleUser
     * const user = await author.user(); // Full User
     */
    get author() {
        const user = this.get("user");
        return (__classPrivateFieldSet(this, _BaseComment_author, __classPrivateFieldGet(this, _BaseComment_author, "f") ?? user ? new SimpleUser_1.SimpleUser(this.client, user) : null, "f"));
    }
    /**
     * Author of the Comment
     * @alias author
     * @example
     * const author = comment.author; // SimpleUser
     * const user = await author.user(); // Full User
     */
    get creator() {
        return this.author;
    }
}
exports.BaseComment = BaseComment;
_BaseComment_author = new WeakMap(), _BaseComment_content = new WeakMap();
exports.default = BaseComment;
//# sourceMappingURL=BaseComment.js.map