"use strict";
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var _BaseContent_creator;
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseContent = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const Base_1 = require("./Base");
const Creator_1 = require("./Creator");
/**
 * The Base Content that all Content Types will extend
 * @extends Base<APIContent>
 */
class BaseContent extends Base_1.Base {
    /**
     * @param client Client instance associated with the Content
     * @param payload Payload of the Content
     */
    constructor(client, payload) {
        super(client, payload);
        _BaseContent_creator.set(this, null);
        this.endpointUrl = ifunny_api_types_1.Endpoints.content(payload.id);
        this.payload = payload;
    }
    /**
     * This data is typically retrieved by using the content's type as a key for the content.
     * @example
     * content.payload[content.type] // Key isn't always the type
     */
    get data() {
        switch (this.payload.type) {
            case ifunny_api_types_1.ContentType.VIDEO_CLIP:
                return this.payload.video_clip ?? null;
            case ifunny_api_types_1.ContentType.VIDEO:
                return this.payload.video ?? null;
            case ifunny_api_types_1.ContentType.VINE:
                return this.payload.vine ?? null;
            case ifunny_api_types_1.ContentType.COUB:
                return this.payload.coub ?? null;
            case ifunny_api_types_1.ContentType.GIF:
            case ifunny_api_types_1.ContentType.GIF_CAPTION:
                return this.payload.gif ?? null;
            case ifunny_api_types_1.ContentType.CAPTION:
                return this.payload.caption ?? null;
            case ifunny_api_types_1.ContentType.PIC:
                return this.payload.pic ?? null;
            case ifunny_api_types_1.ContentType.MEME:
                return this.payload.mem ?? null;
            case ifunny_api_types_1.ContentType.COMICS:
                return this.payload.comics ?? null;
            case ifunny_api_types_1.ContentType.APP:
                return this.payload.app ?? null;
            case ifunny_api_types_1.ContentType.OLD:
            case ifunny_api_types_1.ContentType.DEM:
            default:
                // @ts-ignore
                return this.payload[this.payload.type] ?? null; // ? Currently undocumented datas
        }
    }
    /**
     * The creator of the post
     * @alias creator
     */
    get author() {
        return this.creator;
    }
    /**
     * Content background color
     */
    get bgColor() {
        return this.get("bg_color");
    }
    /**
     * Can the post be boosted?
     */
    get canBeBoosted() {
        return this.get("can_be_boosted");
    }
    /**
     * Content url that can be opened in app
     */
    get canonicalUrl() {
        return this.get("canonical_url");
    }
    /**
     * Copywright information attached to the content
     */
    get copyright() {
        return this.get("copyright") ?? {};
    }
    /**
     * The creator of the post
     * @alias author
     */
    get creator() {
        if (__classPrivateFieldGet(this, _BaseContent_creator, "f"))
            return __classPrivateFieldGet(this, _BaseContent_creator, "f");
        const user = this.get("creator");
        return user ? (__classPrivateFieldSet(this, _BaseContent_creator, __classPrivateFieldGet(this, _BaseContent_creator, "f") ?? new Creator_1.Creator(this.client, user), "f")) : user;
    }
    /**
     * When the content was created
     */
    get createdAt() {
        return new Date(this.get("date_create") * 1000);
    }
    /**
     * Not sure what this is
     */
    get fastStart() {
        return this.get("fast_start");
    }
    /**
     * Title set by iFunny
     */
    get fixedTitle() {
        return this.get("fixed_title");
    }
    /**
     * The ID of the Content.
     */
    get id() {
        return super.id;
    }
    /**
     * Was the post removed by iFunny?
     */
    get isAbused() {
        return this.get("is_abused");
    }
    /**
     * Was the post featured?
     */
    get isFeatured() {
        return this.get("is_featured");
    }
    /**
     * Is the Content pinned by the author?
     */
    get isPinned() {
        return this.get("is_pinned");
    }
    /**
     * Is the Content republished by the Client?
     */
    get isRepublished() {
        return this.get("is_republished");
    }
    /**
     * Is the Content smiled by the Client?
     */
    get isSmiled() {
        return this.get("is_smiled");
    }
    /**
     * When the Content was featured if it was featured
     */
    get featuredAt() {
        const ms = this.get("issue_at");
        return ms ? new Date(ms * 1000) : null;
    }
    /**
     * The tag to use for the 'from' parameter
     */
    get ftag() {
        return this.get("ftag");
    }
    /**
     * The link of the content that can be opened in iFunny
     */
    get link() {
        return this.get("link");
    }
    /**
     * The numbers attached to the Content
     * @alias stats
     */
    get num() {
        return this.get("num");
    }
    /**
     * Text generated from iFunny's OCR (Optical Character Recognition)
     */
    get ocrText() {
        return this.get("ocr_text");
    }
    /**
     * Does the Content use the Old Watermark
     */
    get oldWatermark() {
        return this.get("old_watermark");
    }
    /**
     * When the Content was published or will publish
     */
    get publishedAt() {
        const seconds = this.get("publish_at") * 1000;
        return new Date(seconds);
    }
    /**
     * The risk level of the Content\
     * Default: `1`
     */
    get risk() {
        return this.get("risk");
    }
    /**
     * The shot status of the content\
     * `approved` - Content can be posted in comments\
     * `shot` - Content can't be posted in comments\
     * `hardShot` - Content was removed by iFunny and is not viewable
     */
    get shotStatus() {
        return this.get("shot_status");
    }
    /**
     * The size of the Content
     */
    get size() {
        return this.get("size");
    }
    /**
     * The source of the content if it exists
     */
    get source() {
        return this.get("source");
    }
    /**
     * The state of the Content
     */
    get state() {
        return this.get("state");
    }
    /**
     * The numbers attached to the Content
     * @alias num
     */
    get stats() {
        return this.num;
    }
    /**
     * All tags on the Content
     */
    get tags() {
        return this.get("tags");
    }
    /**
     * Thumbnail of the Content
     */
    get thumbnail() {
        return this.get("thumb");
    }
    /**
     * The Title of the content
     */
    get title() {
        return this.get("title");
    }
    /**
     * URL of the original source if it exists
     */
    get tracebackUrl() {
        return this.get("traceback_url");
    }
    /**
     * The type of the post
     */
    get type() {
        return this.get("type");
    }
    /**
     * URL of the Content
     */
    get url() {
        return this.get("url");
    }
    /**
     * The Content's visibility status\
     * `public` - Content shows up in collective and explore
     * `subscribers` - Content is hidden from Collective and Explore
     * `closed` - Content is not visible by anyone but the author
     */
    get visibility() {
        return this.get("visibility");
    }
    /**
     * When concatenated with a string, this automatically returns the content's id instead of the Content object.
     * @example
     * console.log(`Found post: ${content}`); //  Logs: Found post: 2hu2ab8J
     */
    toString() {
        return this.id;
    }
}
exports.BaseContent = BaseContent;
_BaseContent_creator = new WeakMap();
exports.default = BaseContent;
//# sourceMappingURL=BaseContent.js.map