"use strict";
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var _Creator_user;
Object.defineProperty(exports, "__esModule", { value: true });
exports.Creator = void 0;
const Base_1 = require("./Base");
/**
 * Preresents a Content Creator on iFunny
 * @extends Base<APIContentCreator>
 */
class Creator extends Base_1.Base {
    /**
     * @param client Client instance for the Creator
     * @param payload Payload of the content creator
     */
    constructor(client, payload) {
        super(client, payload);
        /**
         * The Content Creator's User Object
         */
        _Creator_user.set(this, null);
    }
    /**
     * The Content Creator's User Object
     * @returns Promise that resolves to the User Object
     */
    async user() {
        return (__classPrivateFieldSet(this, _Creator_user, __classPrivateFieldGet(this, _Creator_user, "f") ?? await this.client.users.fetch(this.id), "f"));
    }
    /**
     * Is the creator banned?
     * @returns boolean
     */
    get isBanned() {
        return this.get("is_banned");
    }
    /**
     * Is the creator blocked by the Client?
     * @returns boolean
     */
    get isBlocked() {
        return this.get("is_blocked");
    }
    /**
     * Is the creator a deleted user?
     * @returns boolean
     */
    get isDeleted() {
        return this.get("is_deleted");
    }
    /**
     * Is the creator subscribed to the Client?
     * @returns boolean
     */
    get isSubscriber() {
        return this.get("is_in_subscribers");
    }
    /**
     * Is the Client subscribed to the Creator?
     * @returns boolean
     */
    get isSubscription() {
        return this.get("is_in_subscriptions");
    }
    /**
     * Is the Creator verified?
     * @returns boolean
     */
    get isVerified() {
        return this.get("is_verified");
    }
    /**
     * The creator's nick
     * @alias username
     */
    get nick() {
        return this.get("nick");
    }
    /**
     * The creator's nick color
     * @returns A hex color code without the # prefix
     * @example
     * nick_color: "55FF00"
     */
    get nickColor() {
        return this.get("nick_color");
    }
    /**
     * The creator's nums
     * @alias stats
     */
    get num() {
        return this.get("num");
    }
    /**
     * The creator's original nick\
     * ? iFunny sometimes censors users nicknames
     * @example
     * nick: "garespectingyoass"
     * original_nick: "garapingyoass"
     */
    get originalNick() {
        return this.get("original_nick");
    }
    /**
     * The creator's profile photo
     */
    get photo() {
        return this.get("photo");
    }
    /**
     * The creator's rating
     */
    get rating() {
        return this.get("rating");
    }
    /**
     * The creator's stats
     * @alias num
     */
    get stats() {
        return this.num;
    }
    /**
     * Total number of posts the creator has\
     * ? This isn't in Creator.num for some reason
     */
    get totalPosts() {
        return this.get("total_posts");
    }
    /**
     * The creator's username
     * @alias nick
     */
    get username() {
        return this.nick;
    }
    /**
     * When concatenated with a string, this automatically returns the user's nick instead of the User object.
     * @example
     * console.log(`Hello from ${user}!`); //  Logs: Hello from iFunnyChef
     */
    toString() {
        return this.nick;
    }
}
exports.Creator = Creator;
_Creator_user = new WeakMap();
exports.default = Creator;
//# sourceMappingURL=Creator.js.map