"use strict";
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _User_instances, _User_timeline, _User_modifySubscription;
Object.defineProperty(exports, "__esModule", { value: true });
exports.User = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const BaseUser_1 = require("./BaseUser");
const iFunnyError_1 = require("../errors/iFunnyError");
const Feed_1 = __importDefault(require("./Feed"));
/**
 * Represents a user on iFunny
 * @extends BaseUser
 */
class User extends BaseUser_1.BaseUser {
    /**
     * @param client Client instance associated with the User
     * @param payload Payload of the User
     */
    constructor(client, payload) {
        super(client, payload);
        _User_instances.add(this);
        _User_timeline.set(this, null);
    }
    /**
     * Subscribe to the User
     */
    async subscribe() {
        await __classPrivateFieldGet(this, _User_instances, "m", _User_modifySubscription).call(this, "PUT");
    }
    /**
     * Unsubscribe from the User
     */
    async unsubscribe() {
        __classPrivateFieldGet(this, _User_instances, "m", _User_modifySubscription).call(this, "DELETE");
    }
    /**
     * Get the User's timeline object
     * @returns Feed
     */
    get timeline() {
        return (__classPrivateFieldSet(this, _User_timeline, __classPrivateFieldGet(this, _User_timeline, "f") ?? new Feed_1.default(this.client, ifunny_api_types_1.Endpoints.userTimeline(this.id)), "f"));
    }
}
exports.User = User;
_User_timeline = new WeakMap(), _User_instances = new WeakSet(), _User_modifySubscription = 
/**
 * Modify the subscription status of the User
 * @param method "PUT" or "DELETE"
 */
async function _User_modifySubscription(method) {
    if (!this.client.isAuthorized()) {
        throw new iFunnyError_1.iFunnyError(this.client, {
            error: ifunny_api_types_1.IFUNNY_ERRORS.UNAUTHORIZED,
            error_description: "Requested operation is unavailable for guests",
            status: 400,
        });
    }
    if (this.id === this.client.payload.id) {
        return this;
    }
    await this.client.instance.request({
        method,
        url: ifunny_api_types_1.Endpoints.subscribers(this.id),
    });
    return this;
};
exports.default = User;
//# sourceMappingURL=User.js.map