import { APIFeedFrom } from "@ifunny/ifunny-api-types";
import { CachedManager } from "./CachedManager";
import { Client } from "../client/Client";
import { Content } from "../structures/Content";
import { ICachingOptions } from "node-ts-cache";
/**
 * Manages content for the Client
 * @extends CachedManager<Content>
 */
export declare class ContentManager extends CachedManager<typeof Content> {
    /**
     * @param client Client instance
     * @param cacheConfig Config to use for Caching
     */
    constructor(client: Client, cacheConfig: ICachingOptions);
    /**
     * Fetches Content by its Id
     * @param id Id of the content
     * @param cached Should we return the Cached item? (Default: `true`)
     * @returns Content
     */
    fetch(contentOrId: Content | string, cached?: boolean): Promise<Content | null>;
    /**
     * Mark content as read.
     * @param content Content to mark as read
     * @param from Where the content was marked as read.
     */
    markAsRead(content: Content | string | (Content | string)[], from?: APIFeedFrom): Promise<boolean>;
}
export default ContentManager;
//# sourceMappingURL=ContentManager.d.ts.map