import { type APINickColor, type APIProfilePhoto, type APIUserAllSocials, type APIUserBlockType, type APIUserMessagePrivacy, type APIUserProfile, type APIUserProfileNums } from "@ifunny/ifunny-api-types";
import { BanSmall } from "./BanSmall";
import { Base } from "./Base";
import { MemeExperience } from "./MemeExperience";
import type { Client } from "../client/Client";
/**
 * Base User class that user class will inherit from.
 * @extends Base<APIUserProfile>
 */
export declare class BaseUser extends Base<APIUserProfile> {
    /**
     * @param client The client instance
     * @param payload Payload to create the User with
     */
    constructor(client: Client, payload: APIUserProfile);
    /**
     * The user's about text
     * @alias bio
     */
    get about(): string;
    /**
     * Does the user have you blocked?
     */
    get areYouBlocked(): boolean;
    /**
     * Collection of Bans the user has
     */
    get bans(): BanSmall[];
    /**
     * The user's about text
     * @alias about
     */
    get bio(): string;
    /**
     * The block type if the user is blocked
     */
    get blockType(): APIUserBlockType | null;
    /**
     * Can the Client chat with the user?\
     * ? Not checked by the backend
     * @alias is_available_for_chat
     */
    get canChat(): boolean;
    /**
     * The user's chat privacy
     */
    get chatPrivacy(): APIUserMessagePrivacy;
    /**
     * Cover image background color
     */
    get coverColor(): string | null;
    /**
     * Cover imamge url
     */
    get coverUrl(): string | null;
    /**
     * Can the Client chat with the user?\
     * ? Not checked by the backend
     * @alias can_chat
     */
    get isAvailableForChat(): boolean;
    /**
     * Is the user banned?
     */
    get isBanned(): boolean;
    /**
     * Is the user blocked by the Client?
     */
    get isBlocked(): boolean;
    /**
     * Is the user deleted?
     */
    get isDeleted(): boolean;
    /**
     * Is the user's account private?
     */
    get isPrivate(): boolean;
    /**
     * Is the user subscribed to updates?
     */
    get isSubscribedToUpdates(): boolean;
    /**
     * Is the user subscribed to the Client?
     */
    get isSubscriber(): boolean;
    /**
     * Is the client subscribed to the user?
     */
    get isSubscription(): boolean;
    /**
     * Is the user verified?
     */
    get isVerified(): boolean;
    /**
     * The user's unique uri
     * @alias web_url
     */
    get link(): string;
    /**
     * The user's meme experience
     */
    get memeExperience(): MemeExperience;
    /**
     * TODO: Add description for messengerActive
     */
    get messengerActive(): boolean;
    /**
     * TODO: Add description for messenger_token
     */
    get messengerToken(): string;
    /**
     * Nickname of the user
     * @alias username
     */
    get nick(): string;
    /**
     * The nick color of the user if they have one, else null
     */
    get nickColor(): APINickColor | null;
    /**
     * The users `num` object
     * @alias `stats`
     */
    get num(): APIUserProfileNums;
    /**
     * Profile photo of the user
     */
    get profilePhoto(): APIProfilePhoto | null;
    /**
     * All the user's linked social media accounts
     */
    get socials(): APIUserAllSocials | null;
    /**
     * The users  `num` object
     * @alias num
     */
    get stats(): APIUserProfileNums;
    /**
     * The users subscription count
     */
    get totalSubscriptions(): number;
    /**
     * The users subsciber count
     */
    get totalSubscribers(): number;
    /**
     * How many posts the user has on their profile
     */
    get totalPosts(): number;
    /**
     * How many original posts the user has
     */
    get totalOriginalPosts(): number;
    /**
     * How many posts the has that are republishes (***NOT original***)
     */
    get totalRepublishedPosts(): number;
    /**
     * How many features the user has
     */
    get totalFeatures(): number;
    /**
     * How many smiles the user has on their profile
     */
    get totalSmiles(): number;
    /**
     * How many achievements the user has
     */
    get totalAchievements(): number;
    /**
     * Nickname of the user
     * @alias nick
     */
    get username(): string;
    /**
     * When concatenated with a string, this automatically returns the user's nick instead of the User object.
     * @example
     * console.log(`Hello from ${user}!`); //  Logs: Hello from iFunnyChef
     */
    toString(): string;
}
export default BaseUser;
//# sourceMappingURL=BaseUser.d.ts.map