/// <reference types="node" />
import { type APIContent, type APIFeedFrom } from "@ifunny/ifunny-api-types";
import { BaseContent } from "./BaseContent";
import { SimpleUser } from "./SimpleUser";
import { Comment } from "./Comment";
import type { Client } from "../client/Client";
import type { URLSearchParams } from "url";
export type ModifyParams = {
    from?: APIFeedFrom;
    limit?: number;
} | URLSearchParams;
/**
 * Represents content from iFunny
 * @extends BaseContent
 */
export declare class Content extends BaseContent {
    #private;
    /**
     * @param client Client attached to the Content
     * @param payload Payload of the content
     */
    constructor(client: Client, payload: APIContent);
    /**
     * Cycles through users that smiled the post
     * @param limit How many users to return per request (Default: `30`)
     */
    smiles(limit?: number): AsyncGenerator<SimpleUser, void, unknown>;
    /**
     * Smiles the post
     * @param from Where the action occured
     * @returns Was it success
     */
    smile(from?: APIFeedFrom): Promise<boolean>;
    /**
     * Removes the Client's smile
     * @param from Where the action occured
     * @returns Was it success
     */
    removeSmile(from?: APIFeedFrom): Promise<boolean>;
    /**
     * Unsmiles the post
     * @param from Where the action occured
     * @returns Was it success
     */
    unsmile(from?: APIFeedFrom): Promise<boolean>;
    /**
     * Removes the Client's unsmile
     * @param from Where the content was smiled
     * @returns Was the content marked as smiled
     */
    removeUnsmile(from?: APIFeedFrom): Promise<boolean>;
    /**
     * Attempts to delete the content
     * @returns Whether the attempt was successful
     */
    delete(): Promise<boolean>;
    /**
     * Paginate through the comments of the content
     * @param limit How many comments to return per request (Default: `30`)
     * @returns AsyncGenerator<Comment>
     */
    comments(limit?: number): AsyncGenerator<Comment>;
}
export default Content;
//# sourceMappingURL=Content.d.ts.map