import type { APIBanType, APIComment, APIContent, APIMentionUser, APINews, APINewsType, APINewsUser } from "@ifunny/ifunny-api-types";
import type { Nullify } from "../utils/Types";
import Content from "./Content";
import Client from "../client/Client";
/**
 * Represents a News object from the Activity Feed
 */
export declare class News {
    #private;
    /**
     * @param client The Client associated with the News
     * @param news Payload of the News Object
     */
    constructor(client: Client, news: APINews);
    /**
     * The Client associated with the News
     */
    get client(): Client;
    /**
     * Payload of the News
     */
    get payload(): APINews;
    /**
     * Get the value of a property of the News object from the payload
     * @param key Key of the property
     * @returns The value of the property
     */
    protected get<K extends keyof APINews>(key: K): Nullify<APINews[K]>;
    /**
     * The Date of the News object
     */
    get date(): Date;
    /**
     * The type of the News object
     */
    get type(): APINewsType;
    /**
     * The ID of the Ban associated with the News object
     */
    get banId(): string | null;
    /**
     * The message associated with the Ban associated with the News object
     */
    get banMessage(): string | null;
    /**
     * The type of the Ban associated with the News object
     */
    get banType(): APIBanType | null;
    /**
     * The raw comment associated with the News object
     */
    get comment(): APIComment | null;
    /**
     * The content associated with the News object
     */
    get content(): APIContent | null;
    /**
     * The current number of active strikes for the Client
     */
    get countActiveStrike(): number | null;
    /**
     * The date that the Ban or Strike will expire
     */
    get dateUntil(): Date | null;
    /**
     * The date that the Ban or Strike expired
     */
    get expiredAt(): Date | null;
    /**
     * The URL of the image associated with the News object
     */
    get imageUrl(): string | null;
    /**
     * The Content mentioned in this news object
     */
    get mentionContent(): Content | null;
    /**
     * The users mentioned in this news object
     */
    get mentionUsers(): APIMentionUser[] | null;
    /**
     * The type of purchase associated with the News object
     */
    get purchaseType(): string | null;
    /**
     * The raw reply associated with the News object
     */
    get reply(): APIComment | null;
    /**
     * The number of smiles associated with the News object
     */
    get smiles(): number | null;
    /**
     * The ID of the strike associated with the News object
     */
    get strikeId(): string | null;
    /**
     * The message associated with the strike associated with the News object
     */
    get text(): string | null;
    /**
     * The title of the News object
     */
    get title(): string | null;
    /**
     * The URL of the News object
     */
    get url(): string | null;
    /**
     * The User associated with the News object
     */
    get user(): APINewsUser | null;
    /**
     * The username associated with the News object
     */
    get username(): string | null;
}
export default News;
//# sourceMappingURL=News.d.ts.map