import type { APIContentThumbnail, Size } from "@ifunny/ifunny-api-types";
/**
 * Represents a thumbnail for Content on iFunny
 */
export declare class Thumbnail {
    #private;
    /**
     * The regex used to find the thumbnail ID
     */
    static readonly Thumbnail_ID_Regex: RegExp;
    /**
     * @param thumbnail Thumbnail data from the API
     */
    constructor(thumbnail: APIContentThumbnail);
    /**
     * Gets the value for the thumbnail from its key
     * @param key Key for the thumbnail
     * @returns Type safe value from the key
     */
    protected get<K extends keyof APIContentThumbnail>(key: K): APIContentThumbnail[K];
    /**
     * Gets the ID of the thumbnail from its URL.
     * @throws An error if the ID cannot be found in the URL.
     * @returns The ID string.
     */
    get id(): string;
    /**
     * Create a new thumbnail with custom parameters
     * @param params Params for the new thumbnail
     * @param extension File extension for the thumbnail. (Default: `jpg`)
     */
    create(params: string, extension?: "jpg" | " webp"): string;
    /**
     * The content url after cropping out the iFunny Watermark
     */
    get cropped(): string;
    /**
     * Gets the large image URL.
     * @returns The URL string or null if not available.
     */
    get largeUrl(): string;
    /**
     * Gets the large WebP image URL.
     * @returns The URL string or null if not available.
     */
    get largeWebpUrl(): string;
    /**
     * Gets the proportional size of the image.
     * @returns The size object or null if not available.
     */
    get proportionalSize(): Size;
    /**
     * Gets the proportional image URL.
     * @returns The URL string or null if not available.
     */
    get proportionalUrl(): string;
    /**
     * Gets the proportional WebP image URL.
     * @returns The URL string or null if not available.
     */
    get proportionalWebpUrl(): string;
    /**
     * Gets the small image URL.
     * @returns The URL string or null if not available.
     */
    get smallUrl(): string | null;
    /**
     * Gets the image URL.
     * @returns The URL string or null if not available.
     */
    get url(): string;
    /**
     * Gets the WebP image URL.
     * @returns The URL string or null if not available.
     */
    get webpUrl(): string;
    /**
     * Gets the 640px wide image URL.
     * @returns The URL string or null if not available.
     */
    get x640Url(): string;
    /**
     * Gets the 640px wide WebP image URL.
     * @returns The URL string or null if not available.
     */
    get x640WebpUrl(): string;
}
export default Thumbnail;
//# sourceMappingURL=Thumbnail.d.ts.map